Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1609)

Unified Diff: content/public/test/layouttest_support.h

Issue 2415083002: Move Device Sensors client files from Blink to //device/sensors client lib (Closed)
Patch Set: Rebase Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/renderer/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/test/layouttest_support.h
diff --git a/content/public/test/layouttest_support.h b/content/public/test/layouttest_support.h
index f23eafb34621394744ac5f3828ebfa390830d2b2..0d8962b882f3dd0523973e777b50d2bb899319ad 100644
--- a/content/public/test/layouttest_support.h
+++ b/content/public/test/layouttest_support.h
@@ -18,8 +18,6 @@
class GURL;
namespace blink {
-class WebDeviceMotionData;
-class WebDeviceOrientationData;
class WebInputEvent;
class WebLocalFrame;
struct WebSize;
@@ -29,6 +27,11 @@ class WebWidget;
class WebURLResponse;
}
+namespace device {
+class MotionData;
+class OrientationData;
+}
+
namespace gfx {
class ICCProfile;
}
@@ -104,13 +107,13 @@ void SetMockGamepadProvider(std::unique_ptr<RendererGamepadProvider> provider);
// a listener through BlinkPlatformImpl::setDeviceLightListener().
void SetMockDeviceLightData(const double data);
// Sets WebDeviceMotionData that should be used when registering
// a listener through BlinkPlatformImpl::setDeviceMotionListener().
-void SetMockDeviceMotionData(const blink::WebDeviceMotionData& data);
+void SetMockDeviceMotionData(const device::MotionData& data);
-// Sets WebDeviceOrientationData that should be used when registering
+// Sets OrientationData that should be used when registering
// a listener through BlinkPlatformImpl::setDeviceOrientationListener().
-void SetMockDeviceOrientationData(const blink::WebDeviceOrientationData& data);
+void SetMockDeviceOrientationData(const device::OrientationData& data);
// Returns the length of the local session history of a render view.
int GetLocalSessionHistoryLength(RenderView* render_view);
« no previous file with comments | « no previous file | content/renderer/BUILD.gn » ('j') | no next file with comments »
@@ -104,13 +107,13 @@ void SetMockGamepadProvider(std::unique_ptr<RendererGamepadProvider> provider);
// a listener through BlinkPlatformImpl::setDeviceLightListener().
void SetMockDeviceLightData(const double data);
-// Sets WebDeviceMotionData that should be used when registering
+// Sets MotionData that should be used when registering
// a listener through BlinkPlatformImpl::setDeviceMotionListener().

Powered by Google App Engine
This is Rietveld 408576698